==> viha-5.15.tar.gz: viha-5.15/paivystys-loppu.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = basename(__FILE__);

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation lopettaminen</title>
</head>
" . body_bgcolor() . "
<h1>Operaation lopettaminen</h1>
";

hallinnolliset_linkit();

$finish = get_txt('finish');
$confirm = get_txt('confirm');

# ei lapsille eik heikkohermoisille!
oltava_useita($file);

if ($confirm != '') {
  $ret = paivystys_id_ok($herja,s('paivystys'));
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $p = s('paivystys');
    $sql =
      "UPDATE jarjesto
       SET paivystys_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    # we do persons one by one because of in-out - records
    $sql = "SELECT id FROM hlo WHERE paivystys_id = $p";
    $result = my_mysql_query($sql);
    if ($result) {
      while ($a = mysql_fetch_array($result)) {
	$sql1 =
	  "UPDATE hlo
              SET ryhma_id = 1,
                  hlo_tila_id = 5,
                  hlo_asema_id = 5,
                  halyssa = 0,
                  ts = '$now'
            WHERE id = $a[id]";
	my_mysql_query($sql1,true,true);
	add_hlo_ajat_sql("WHERE id = $a[id]");
	$sql1 =
	  "UPDATE hlo
              SET paivystys_id = 1,
                  ts = '$now'
            WHERE id = $a[id]";
	my_mysql_query($sql1,true,true);
	add_hlo_ajat_sql("WHERE id = $a[id]");
      } # while
    } # if result
    $sql =
      "UPDATE laite
       SET paivystys_id = 1,
           ryhma_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    $sql =
      "UPDATE tavara
       SET paivystys_id = 1,
           ryhma_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    $sql =
      "UPDATE ryhma
       SET ryhma_tila_id = 12,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    echo "<p>Operaatio " . ota_paivystys_nimi() . " lopetettu.\n";
    taktinen_loki("Operaatio " . ota_paivystys_nimi() . " lopetettu.\n");
  }
  p_herja($ret,$herja);
 }

# finishable tells if we can actually finish this operation
if ($finish != '') {
  $finishable = 0;
  $ret = paivystys_id_ok($herja,s('paivystys'));
  if ($ret != 2) {
    $finishable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaation " . ota_paivystys_nimi() . " lopettaminen</h2>\n";

echo "
<p>Operaatiota lopetettaessa merkitn kaikki operaatioon osallistuneet
henkilt ja jrjestt vapaiksi. Jrjestjen hlytysryhmt tyhjennetn.
Ryhmt merkitn lopettaneiksi.
Samalla vapautetaan kaikki kalusto operaation kytst.
<p><font color=red>Operaation lopettamista ei voi peruuttaa muuten kuin
liittmll kaikki edell mainitut ksin uudelleen operaatioon ja palauttamalla
ksin ryhmien tilat.</font>
";

if ($finish != "") {
  if ($finishable) {
    echo "<p>Oletko varma?\n";
    echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA LOPETUS\">\n";
  } else {
    echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
  }
 } else {
  echo "<input type=\"submit\" name=\"finish\" value=\"LOPETA OPERAATIO\">\n";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys-loppu.php,v 1.25 2009/06/06 15:43:53 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/paivystys-loppu.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "paivystys";
$file = basename(__FILE__);

include "common.php";
include "paivystys-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation lopettaminen</title>
</head>
" . body_bgcolor() . "
<h1>Operaation lopettaminen</h1>
";

hallinnolliset_linkit();

$finish = get_txt('finish');
$confirm = get_txt('confirm');

# ei lapsille eik heikkohermoisille!
oltava_useita($file);

if ($confirm != '') {
  $ret = paivystys_id_ok($herja,s('paivystys'));
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $p = s('paivystys');
    $sql =
      "UPDATE jarjesto
       SET paivystys_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    # we do persons one by one because of in-out - records
    $sql = "SELECT id FROM hlo WHERE paivystys_id = $p";
    $result = my_mysql_query($sql);
    if ($result) {
      while ($a = mysql_fetch_array($result)) {
	$sql1 =
	  "UPDATE hlo
              SET ryhma_id = 1,
                  hlo_tila_id = 5,
                  hlo_asema_id = 5,
                  halyssa = 0,
                  ts = '$now'
            WHERE id = $a[id]";
	my_mysql_query($sql1,true,true);
	add_hlo_ajat_sql("WHERE id = $a[id]");
	$sql1 =
	  "UPDATE hlo
              SET paivystys_id = 1,
                  ts = '$now'
            WHERE id = $a[id]";
	my_mysql_query($sql1,true,true);
	add_hlo_ajat_sql("WHERE id = $a[id]");
      } # while
    } # if result
    $sql =
      "UPDATE laite
       SET paivystys_id = 1,
           ryhma_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    $sql =
      "UPDATE tavara
       SET paivystys_id = 1,
           ryhma_id = 1,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    $sql =
      "UPDATE ryhma
       SET ryhma_tila_id = 12,
           ts = '$now'
       WHERE paivystys_id = $p";
    my_mysql_query($sql,true,true);
    $msg = "Operaatio " . muotoile_operaatio() . " lopetettu.";
    tehty($msg);
    taktinen_loki($msg);
  }
  p_herja($ret,$herja);
 }

# finishable tells if we can actually finish this operation
if ($finish != '') {
  $finishable = 0;
  $ret = paivystys_id_ok($herja,s('paivystys'));
  if ($ret != 2) {
    $finishable = 1;
  }
  p_herja($ret,$herja);
 }

echo "<form action=\"\" method=\"GET\">\n";

echo "<h2>Operaation " . muotoile_operaatio() . " lopettaminen</h2>\n";

echo "
<p>Operaatiota lopetettaessa merkitn kaikki operaatioon osallistuneet
henkilt ja jrjestt vapaiksi. Jrjestjen hlytysryhmt tyhjennetn.
Ryhmt merkitn lopettaneiksi.
Samalla vapautetaan kaikki kalusto operaation kytst.
<p><font color=red>Operaation lopettamista ei voi peruuttaa muuten kuin
liittmll kaikki edell mainitut ksin uudelleen operaatioon ja palauttamalla
ksin ryhmien tilat.</font>
";

if ($finish != "") {
  if ($finishable) {
    echo "<p>Oletko varma?\n";
    echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA LOPETUS\">\n";
  } else {
    echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
  }
 } else {
  echo "<input type=\"submit\" name=\"finish\" value=\"LOPETA OPERAATIO\">\n";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: paivystys-loppu.php,v 1.27 2009/10/05 16:07:04 riku Exp $ -->
